@@ -1,4 +1,4 @@
-__version__ = "2.0.0"
+__version__ = "2.1.0"
 
 
 from platform import system
@@ -31,6 +31,7 @@ from .models import (
     ADAPTER_PRODUCT,
     ADAPTER_PRODUCT_ID,
     ADAPTER_SW_VERSION,
+    ADAPTER_TYPE,
     ADAPTER_VENDOR_ID,
     AdapterDetails,
 )
@@ -47,38 +48,39 @@ from .systems.linux_hci import get_adapters_from_hci
 from .util import adapter_human_name, adapter_model, adapter_unique_name
 
 __all__ = [
-    "get_manufacturer_from_mac",
+    "ADAPTER_ADDRESS",
+    "ADAPTER_CONNECTION_SLOTS",
+    "ADAPTER_HW_VERSION",
+    "ADAPTER_MANUFACTURER",
+    "ADAPTER_PASSIVE_SCAN",
+    "ADAPTER_PRODUCT",
+    "ADAPTER_PRODUCT_ID",
+    "ADAPTER_SW_VERSION",
+    "ADAPTER_TYPE",
+    "ADAPTER_VENDOR_ID",
+    "DEFAULT_ADDRESS",
+    "DEFAULT_CONNECTION_SLOTS",
+    "MACOS_DEFAULT_BLUETOOTH_ADAPTER",
+    "UNIX_DEFAULT_BLUETOOTH_ADAPTER",
+    "WINDOWS_DEFAULT_BLUETOOTH_ADAPTER",
+    "AdapterDetails",
     "AdvertisementHistory",
-    "BluetoothAdapters",
     "BlueZDBusObjects",
+    "BluetoothAdapters",
     "DiscoveredDeviceAdvertisementData",
     "DiscoveredDeviceAdvertisementDataDict",
     "DiscoveryStorageType",
     "adapter_human_name",
-    "adapter_unique_name",
     "adapter_model",
-    "discovered_device_advertisement_data_to_dict",
+    "adapter_unique_name",
     "discovered_device_advertisement_data_from_dict",
+    "discovered_device_advertisement_data_to_dict",
     "expire_stale_scanner_discovered_device_advertisement_data",
-    "get_adapters_from_hci",
-    "get_bluetooth_adapters",
-    "get_bluetooth_adapter_details",
-    "get_dbus_managed_objects",
     "get_adapters",
+    "get_adapters_from_hci",
+    "get_bluetooth_adapter_details",
+    "get_bluetooth_adapters",
+    "get_dbus_managed_objects",
+    "get_manufacturer_from_mac",
     "load_history_from_managed_objects",
-    "AdapterDetails",
-    "ADAPTER_ADDRESS",
-    "ADAPTER_CONNECTION_SLOTS",
-    "ADAPTER_SW_VERSION",
-    "ADAPTER_HW_VERSION",
-    "ADAPTER_PASSIVE_SCAN",
-    "ADAPTER_MANUFACTURER",
-    "ADAPTER_PRODUCT",
-    "ADAPTER_VENDOR_ID",
-    "ADAPTER_PRODUCT_ID",
-    "WINDOWS_DEFAULT_BLUETOOTH_ADAPTER",
-    "MACOS_DEFAULT_BLUETOOTH_ADAPTER",
-    "UNIX_DEFAULT_BLUETOOTH_ADAPTER",
-    "DEFAULT_ADDRESS",
-    "DEFAULT_CONNECTION_SLOTS",
 ]
